==> haskell-loop-0.3.0-25-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-loop.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: loop
version: 0.3.0
id: loop-0.3.0-KA4a4RzBfhkLNSYfBqLpFC
key: loop-0.3.0-KA4a4RzBfhkLNSYfBqLpFC
license: MIT
copyright: 2014 Niklas Hambüchen <mail@nh2.me>
maintainer: Niklas Hambüchen <mail@nh2.me>
author: Niklas Hambüchen <mail@nh2.me>
stability: experimental
homepage: https://github.com/nh2/loop
synopsis: Fast loops (for when GHC can'\''t optimize forM_)
description:
    This package provides a convenient and fast alternative to the common
    `forM_ [1..n]` idiom, which in many cases GHC cannot fuse to efficient
    code.
    .
    See <https://ghc.haskell.org/trac/ghc/ticket/8763>.
category: Control
abi: 03f75d75c665150957eca2603f844614
exposed: True
exposed-modules:
    Control.Loop Control.Loop.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/loop-0.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/loop-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/loop-0.3.0
hs-libraries: HSloop-0.3.0-KA4a4RzBfhkLNSYfBqLpFC
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-loop/html/loop.haddock
haddock-html: /usr/share/doc/haskell-loop/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-loop-0.3.0-26-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-loop.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: loop
version: 0.3.0
id: loop-0.3.0-2BNN0gDW8B9Zp3u0YYNmp
key: loop-0.3.0-2BNN0gDW8B9Zp3u0YYNmp
license: MIT
copyright: 2014 Niklas Hambüchen <mail@nh2.me>
maintainer: Niklas Hambüchen <mail@nh2.me>
author: Niklas Hambüchen <mail@nh2.me>
stability: experimental
homepage: https://github.com/nh2/loop
synopsis: Fast loops (for when GHC can'\''t optimize forM_)
description:
    This package provides a convenient and fast alternative to the common
    `forM_ [1..n]` idiom, which in many cases GHC cannot fuse to efficient
    code.
    .
    See <https://ghc.haskell.org/trac/ghc/ticket/8763>.
category: Control
abi: d8bdf2ce08921f8f2a38de4000a81226
exposed: True
exposed-modules:
    Control.Loop Control.Loop.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/loop-0.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/loop-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/loop-0.3.0
hs-libraries: HSloop-0.3.0-2BNN0gDW8B9Zp3u0YYNmp
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-loop/html/loop.haddock
haddock-html: /usr/share/doc/haskell-loop/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
